@@ -11,6 +11,20 @@ class TextBox(WidgetBase):
     CURSOR_INTERVAL = 400
 
     def __init__(self, win, x, y, width, height, **kwargs):
+        """ A customisable textbox for Pygame
+
+        :param win: Surface on which to draw
+        :type win: pygame.Surface
+        :param x: X-coordinate of top left
+        :type x: int
+        :param y: Y-coordinate of top left
+        :type y: int
+        :param width: Width of button
+        :type width: int
+        :param height: Height of button
+        :type height: int
+        :param kwargs: Optional parameters
+        """
         super().__init__(win, x, y, width, height)
 
         self.selected = False
@@ -53,6 +67,11 @@ class TextBox(WidgetBase):
         self.onSubmitParams = kwargs.get('onSubmitParams', ())
 
     def listen(self, events):
+        """ Wait for inputs
+
+        :param events: Use pygame.event.get()
+        :type events: list of pygame.event.Event
+        """
         if self.keyDown:
             self.updateRepeatKey()
 
@@ -125,6 +144,7 @@ class TextBox(WidgetBase):
                     self.escape = False
 
     def draw(self):
+        """ Display to surface """
         if not self.hidden:
             if self.selected:
                 self.updateCursor()
@@ -168,16 +188,16 @@ class TextBox(WidgetBase):
             ]
 
             for rect in borderRects:
-                pygame.draw.rect(win, self.borderColour, rect)
+                pygame.draw.rect(self.win, self.borderColour, rect)
 
             for circle in borderCircles:
-                pygame.draw.circle(win, self.borderColour, circle, self.radius)
+                pygame.draw.circle(self.win, self.borderColour, circle, self.radius)
 
             for rect in backgroundRects:
-                pygame.draw.rect(win, self.colour, rect)
+                pygame.draw.rect(self.win, self.colour, rect)
 
             for circle in backgroundCircles:
-                pygame.draw.circle(win, self.colour, circle, self.radius)
+                pygame.draw.circle(self.win, self.colour, circle, self.radius)
 
             x = [self.x + self.textOffsetLeft]
             for c in self.text:
@@ -226,6 +246,9 @@ class TextBox(WidgetBase):
                 )
             )
 
+    def setText(self, text):
+        self.text = [c for c in str(text)]
+
     def getText(self):
         return ''.join(self.text)
 
